cytoflow.operations package
===========================

Submodules
----------

cytoflow.operations.autofluorescence module
-------------------------------------------

.. automodule:: cytoflow.operations.autofluorescence
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.bead_calibration module
-------------------------------------------

.. automodule:: cytoflow.operations.bead_calibration
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.binning module
----------------------------------

.. automodule:: cytoflow.operations.binning
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.bleedthrough_linear module
----------------------------------------------

.. automodule:: cytoflow.operations.bleedthrough_linear
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.bleedthrough_piecewise module
-------------------------------------------------

.. automodule:: cytoflow.operations.bleedthrough_piecewise
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.channel_stat module
---------------------------------------

.. automodule:: cytoflow.operations.channel_stat
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.color_translation module
--------------------------------------------

.. automodule:: cytoflow.operations.color_translation
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.frame_stat module
-------------------------------------

.. automodule:: cytoflow.operations.frame_stat
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.gaussian_1d module
--------------------------------------

.. automodule:: cytoflow.operations.gaussian_1d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.gaussian_2d module
--------------------------------------

.. automodule:: cytoflow.operations.gaussian_2d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.i_operation module
--------------------------------------

.. automodule:: cytoflow.operations.i_operation
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.import_op module
------------------------------------

.. automodule:: cytoflow.operations.import_op
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.polygon module
----------------------------------

.. automodule:: cytoflow.operations.polygon
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.quad module
-------------------------------

.. automodule:: cytoflow.operations.quad
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.range module
--------------------------------

.. automodule:: cytoflow.operations.range
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.range2d module
----------------------------------

.. automodule:: cytoflow.operations.range2d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.ratio module
--------------------------------

.. automodule:: cytoflow.operations.ratio
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.threshold module
------------------------------------

.. automodule:: cytoflow.operations.threshold
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.operations.xform_stat module
-------------------------------------

.. automodule:: cytoflow.operations.xform_stat
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.operations
    :members:
    :undoc-members:
    :show-inheritance:
